@@ -2,37 +2,30 @@
 #ifndef _GLIBMM_MAIN_H
 #define _GLIBMM_MAIN_H
 
-/* $Id: main.h 750 2008-12-12 01:09:55Z jjongsma $ */
-
 /* Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib.h>
-
-#include <vector>
-#include <sigc++/sigc++.h>
-
 #include <glibmmconfig.h>
 #include <glibmm/refptr.h>
 #include <glibmm/timeval.h>
 #include <glibmm/priorities.h>
-
-GLIBMM_USING_STD(vector)
-
+#include <sigc++/sigc++.h>
+#include <glib.h>
+#include <vector>
 
 namespace Glib
 {
@@ -41,13 +34,11 @@ class Cond;
 class Mutex;
 class IOChannel;
 
-
 /** @defgroup MainLoop The Main Event Loop
  * Manages all available sources of events.
  * @{
  */
 
-
 /** A bitwise combination representing an I/O condition to watch for on an
  * event source.
  * The flags correspond to those used by the <tt>%poll()</tt> system call
@@ -200,7 +191,7 @@ public:
    * @param priority The priority of the new event source.
    * @return A connection handle, which can be used to disconnect the handler.
    *
-   * @newin2p14
+   * @newin{2,14}
    */
   sigc::connection connect_seconds(const sigc::slot<bool>& slot, unsigned int interval,
                            int priority = PRIORITY_DEFAULT);
